@@ -25,7 +25,6 @@
 #include "package.h"
 #include "uihelper.h"
 #include "wmhelper.h"
-#include "treeviewpackagesitemdelegate.h"
 #include "searchbar.h"
 #include "utils.h"
 #include "globals.h"
@@ -33,6 +32,7 @@
 #include "optionsdialog.h"
 #include "termwidget.h"
 #include "aurvote.h"
+#include "alpmbackend.h"
 
 #include <QDropEvent>
 #include <QMimeData>
@@ -162,7 +162,7 @@ bool MainWindow::isNotifierBusy()
   }
 
   QDataStream in(&socket);
-  in.setVersion(QDataStream::Qt_5_10);
+  in.setVersion(QDataStream::Qt_5_15);
   QString octopiResponse;
 
   do
@@ -251,7 +251,7 @@ void MainWindow::show()
     QMainWindow::show();
 
     m_listOfVisitedPackages.clear();
-    m_indOfVisitedPackage = 0;
+    m_indOfVisitedPackage = -1;
 
     if (Package::hasPacmanDatabase())
     {
@@ -280,7 +280,7 @@ void MainWindow::onSendInfoToOctopiHelper()
   QString msg;
   QByteArray block;
   QDataStream out(&block, QIODevice::WriteOnly);
-  out.setVersion(QDataStream::Qt_5_10);
+  out.setVersion(QDataStream::Qt_5_15);
 
   //Is octopi-helper running?
   bool isHelperExecuting=UnixCommand::isOctopiHelperRunning();
@@ -391,7 +391,6 @@ void MainWindow::onPackageGroupChanged()
   if (isAllGroupsSelected())
   {
     if (m_commandExecuting == ectn_NONE && m_initializationCompleted) m_actionSwitchToForeignTool->setEnabled(true);
-    //ui->actionSearchByName->setChecked(true);
     m_actionLastSearchMethod->setChecked(true);
     tvPackagesSearchColumnChanged(ui->actionSearchByName);
   }
@@ -475,8 +474,8 @@ QTextBrowser *MainWindow::getOutputTextBrowser()
 void MainWindow::showAnchorDescription(const QUrl &link)
 {
   if (link.toString().contains(QLatin1String("goto:")))
-  {            
-    QString pkgName = link.toString().mid(5);
+  {
+    QString pkgName = link.toString().mid(5).remove(QStringLiteral("[installed]"), Qt::CaseInsensitive).trimmed();
     //Let's remove any "<" and "<=" symbol...
     pkgName.remove(QRegularExpression(QStringLiteral("%3C\\S*")));
     pkgName.remove(QRegularExpression(QStringLiteral("\\=\\S*")));
@@ -489,6 +488,7 @@ void MainWindow::showAnchorDescription(const QUrl &link)
 
     PkgDesc pkgDesc;
     pkgDesc.name = pkgName;
+
     pkgDesc.description = package->description;
     pkgDesc.isForeign = (package->status == ectn_FOREIGN || package->status == ectn_FOREIGN_OUTDATED);
 
@@ -529,6 +529,7 @@ void MainWindow::positionInPackageList(const QString &pkgName)
       ui->tvPackages->scrollTo(proxyIndex, QAbstractItemView::PositionAtCenter);
       ui->tvPackages->setCurrentIndex(proxyIndex);
       changeTabWidgetPropertiesIndex(ctn_TABINDEX_INFORMATION);
+      ui->tvPackages->setFocus();
     }
   }
   if (foundItems.count() == 0 || !proxyIndex.isValid())
@@ -537,9 +538,8 @@ void MainWindow::positionInPackageList(const QString &pkgName)
     disconnect(ui->twProperties, SIGNAL(currentChanged(int)), this, SLOT(changedTabIndex()));
     ensureTabVisible(ctn_TABINDEX_INFORMATION);
     connect(ui->twProperties, SIGNAL(currentChanged(int)), this, SLOT(changedTabIndex()));
+    ui->tvPackages->setFocus();
   }
-
-  ui->tvPackages->setFocus();
 }
 
 /*
@@ -549,8 +549,16 @@ void MainWindow::outputTextBrowserAnchorClicked(const QUrl &link)
 {
   if (link.toString().contains(QLatin1String("goto:")))
   {
-    QString pkgName = link.toString().mid(5);
+    QString pkgName = link.toString().mid(5).remove(QStringLiteral("[installed]"), Qt::CaseInsensitive).trimmed();
     if (pkgName == QLatin1String("sh")) pkgName = QStringLiteral("bash");
+
+#ifdef ALPM_BACKEND
+    if (AlpmBackend::getPackageVersion(pkgName).isEmpty())
+    {
+      return;
+    }
+#endif
+
     bool indIncremented = false;
     const QItemSelectionModel*const selectionModel = ui->tvPackages->selectionModel();
 
@@ -606,6 +614,7 @@ void MainWindow::outputTextBrowserAnchorClicked(const QUrl &link)
     if (!indIncremented) m_indOfVisitedPackage++;
 
     if (!m_leFilterPackage->text().isEmpty()) m_leFilterPackage->clear();
+
     positionInPackageList(pkgName);
   }
   //Otherwise, it's a remote URL which needs to be opened outside Octopi
@@ -1065,22 +1074,13 @@ void MainWindow::execKeyActionOnPackage(CommandExecuting command)
       {
         if (package->installed() && command == ectn_REMOVE)
         {
-          /*if (package->repository == StrConstants::getForeignRepositoryName())
-          {
-            doRemoveAURPackage();
-          }*/
-          if (package->repository == StrConstants::getForeignRepositoryName())
-          {
+          //if (package->repository == StrConstants::getForeignRepositoryName())
+          {           
             insertIntoRemovePackage();
           }
         }
         else if (command == ectn_INSTALL)
         {
-          /*if (package->repository == StrConstants::getForeignRepositoryName())
-          {
-            doInstallAURPackage();
-          }*/
-          //if (package->repository != StrConstants::getForeignRepositoryName())
           if (UnixCommand::getLinuxDistro() != ectn_KAOS && package->repository != StrConstants::getForeignRepositoryName())
           {
             insertIntoInstallPackage();
@@ -1094,34 +1094,46 @@ void MainWindow::execKeyActionOnPackage(CommandExecuting command)
     }
     else //There are more than 1 package selected
     {
+      int countToInstall = 0;
+      int countToRemove = 0;
+
       for(QModelIndex item: selectedRows)
       {
         const PackageRepository::PackageData*const package = m_packageModel->getData(item);
 
-        if (package->repository == StrConstants::getForeignRepositoryName())
+        if (command == ectn_INSTALL && package->repository != StrConstants::getForeignRepositoryName())
+        {
+          countToInstall++;
+          //insertIntoInstallPackage();
+        }
+
+        else if (package->installed() && command == ectn_REMOVE && !package->required)
+        {
+          countToRemove++;
+          //insertIntoRemovePackage();
+        }
+
+        else if (package->repository == StrConstants::getForeignRepositoryName())
         {
           if (!isAURGroupSelected() && package->installed() && command == ectn_REMOVE)
           {
-            insertIntoRemovePackage(&item);
+            countToRemove++; //insertIntoRemovePackage();
           }
           else if (isAURGroupSelected())
           {
             if (command == ectn_INSTALL)
-              insertIntoInstallPackage(&item);
+              countToInstall++; //insertIntoInstallPackage();
             else if (package->installed() && command == ectn_REMOVE)
-              insertIntoRemovePackage(&item);
+              countToRemove++; //insertIntoRemovePackage();
           }
         }
-        if (command == ectn_INSTALL && package->repository != StrConstants::getForeignRepositoryName())
-        {
-          insertIntoInstallPackage(&item);
-        }
-        else if (package->installed() && command == ectn_REMOVE && !package->required)
-        {
-          insertIntoRemovePackage(&item);
-        }
       }
-    }
+
+      if (countToRemove == selectedRows.count())
+        insertIntoRemovePackage();
+      else if (countToInstall == selectedRows.count())
+        insertIntoInstallPackage();
+    } // End of 'more than 1 package selected'
   }
 }
 
@@ -1855,8 +1867,8 @@ void MainWindow::invalidateTabs()
     return;
   }
 
-  connect(ui->tvPackages->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-          this, SLOT(invalidateTabs()));
+  //connect(ui->tvPackages->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+  //        this, SLOT(invalidateTabs()));
 }
 
 /*
