@@ -22,6 +22,8 @@
  * This is MainWindow's refresh UI components related code
  */
 
+#include <iostream>
+#include <cassert>
 #include "mainwindow.h"
 #include "src/ui/octopitabinfo.h"
 #include "searchlineedit.h"
@@ -29,9 +31,8 @@
 #include "strconstants.h"
 #include "uihelper.h"
 #include "globals.h"
-#include <iostream>
-#include <cassert>
 #include "aurvote.h"
+#include "utils.h"
 
 #include <QElapsedTimer>
 #include <QTimer>
@@ -874,7 +875,17 @@ void MainWindow::buildPackageList()
   }
 
   if (isAllGroupsSelected()) m_packageModel->applyFilter(m_selectedViewOption, m_selectedRepository, QLatin1String(""));
-  if (m_leFilterPackage->text() != QLatin1String("")) reapplyPackageFilter();
+  //if (m_leFilterPackage->text() != QLatin1String("")) reapplyPackageFilter();
+
+  //reapplyPackageFilter(); DANGER
+
+  if(m_debugInfo)
+    std::cout << "Time elapsed after applying filters to the treeview: " << m_time->elapsed() << " mili seconds." << std::endl;
+
+  QModelIndex maux = m_packageModel->index(0, 0, QModelIndex());
+  ui->tvPackages->setCurrentIndex(maux);
+  ui->tvPackages->scrollTo(maux, QAbstractItemView::PositionAtCenter);
+  ui->tvPackages->setCurrentIndex(maux);
 
   list->clear();
   delete list;
@@ -937,19 +948,20 @@ void MainWindow::buildPackageList()
       QApplication::restoreOverrideCursor();
       doInstallLocalPackages();
     }
-  }
 
-  QModelIndex maux = m_packageModel->index(0, 0, QModelIndex());
-  ui->tvPackages->setCurrentIndex(maux);
-  ui->tvPackages->scrollTo(maux, QAbstractItemView::PositionAtCenter);
-  ui->tvPackages->setCurrentIndex(maux);
+    //reapplyPackageFilter(); //DANGER
+  }// end of firstime
 
+  reapplyPackageFilter();
   resizePackageView();
-
   refreshToolBar();
+
   m_refreshPackageLists = true;
   m_refreshForeignPackageList = true;
 
+  if(m_debugInfo)
+    std::cout << "Time elapsed after refreshToolBar(): " << m_time->elapsed() << " mili seconds." << std::endl;
+
   if (searchOutdatedPackages) m_outdatedAURTimer->start();
   else
   {
@@ -957,8 +969,11 @@ void MainWindow::buildPackageList()
 
     QModelIndex mi = ui->tvPackages->currentIndex();
     m_packageRepo.setAUROutdatedData(m_foreignPackageList, *m_outdatedAURStringList);
-    //m_packageRepo.setForeignData(m_foreignPackageList, *m_outdatedAURStringList);
+    std::cout << "Time elapsed after setting AURoutdatedData: " << m_time->elapsed() << " mili seconds." << std::endl;
+
     ui->tvPackages->setCurrentIndex(mi);
+
+    //std::cout << "Time elapsed after setting current index: " << m_time->elapsed() << " mili seconds." << std::endl;
     m_leFilterPackage->setFocus();
   }
 
@@ -969,6 +984,8 @@ void MainWindow::buildPackageList()
     delete m_cic;
     m_cic = nullptr;
   }
+
+  //changePackageListModel(ectn_INSTALLED_PKGS, QStringLiteral("garuda"));
 }
 
 void MainWindow::refreshOutdatedPackageList()
@@ -1717,7 +1734,7 @@ void MainWindow::refreshTabFiles(bool clearContents, bool neverQuit)
 
       if(isDir)
       {
-        if ( first )
+        if (first)
         {
           item = new QStandardItem ( IconHelper::getIconFolder(), baseFileName );
           item->setAccessibleDescription(QLatin1String("directory ") + item->text());
