@@ -25,7 +25,6 @@
 #include "ui_mainwindow.h"
 #include "mainwindow.h"
 #include "uihelper.h"
-#include "wmhelper.h"
 #include "strconstants.h"
 #include "transactiondialog.h"
 #include "multiselectiondialog.h"
@@ -36,6 +35,7 @@
 #include "termwidget.h"
 #include "aurvote.h"
 #include "constants.h"
+#include "utils.h"
 
 #include <QComboBox>
 #include <QProgressBar>
@@ -272,80 +272,76 @@ void MainWindow::insertIntoRemovePackage(QModelIndex *indexToInclude)
   qApp->processEvents();
   QStringList dependencies;
 
-  //if (!isAURGroupSelected())
+  bool checkDependencies=false;
+  //ensureTabVisible(ctn_TABINDEX_ACTIONS);
+  QModelIndexList selectedRows;
+
+  if (indexToInclude == nullptr)
+    selectedRows = ui->tvPackages->selectionModel()->selectedRows();
+  else
   {
-    bool checkDependencies=false;
-    //ensureTabVisible(ctn_TABINDEX_ACTIONS);
-    QModelIndexList selectedRows;
+    selectedRows.append(*indexToInclude);
+  }
 
-    if (indexToInclude == nullptr)
-      selectedRows = ui->tvPackages->selectionModel()->selectedRows();
-    else
+  //First, let's see if we are dealing with a package group
+  if(!isAURGroupSelected() && !isAllGroupsSelected())
+  {
+    //If we are trying to remove all the group's packages, why not remove the entire group?
+    if(selectedRows.count() == m_packageModel->getPackageCount())
     {
-      selectedRows.append(*indexToInclude);
-    }
-
-    //First, let's see if we are dealing with a package group
-    if(!isAURGroupSelected() && !isAllGroupsSelected())
-    {
-      //If we are trying to remove all the group's packages, why not remove the entire group?
-      if(selectedRows.count() == m_packageModel->getPackageCount())
-      {
-        insertRemovePackageIntoTransaction(getSelectedGroup());
-        return;
-      }
-    }
-
-    QString removeCmd = m_removeCommand;
-    if (removeCmd == QLatin1String("Rcs") )
-    {
-      checkDependencies = true;
-    }
-
-    for(QModelIndex item: qAsConst(selectedRows))
-    {
-      const PackageRepository::PackageData*const package = m_packageModel->getData(item);
-      if (package == nullptr) {
-        assert(false);
-        continue;
-      }
-
-      if(checkDependencies)
-      {
-        QStringList *targets = Package::getTargetRemovalList(package->name, removeCmd);
-
-        for(const QString& target: qAsConst(*targets))
-        {
-          int separator = target.lastIndexOf(QLatin1String("-"));
-          QString candidate = target.left(separator);
-          separator = candidate.lastIndexOf(QLatin1String("-"));
-          candidate = candidate.left(separator);
-
-          if (candidate != package->name)
-          {
-            dependencies.append(candidate);
-          }
-        }
-
-        if (dependencies.count() > 0)
-        {
-          if (!dependencies.at(0).contains(QLatin1String("HoldPkg was found in")))
-          {
-            if (!insertIntoRemovePackageDeps(dependencies))
-            {
-              return;
-            }
-          }
-        }
-      }
-
-      insertRemovePackageIntoTransaction(package->repository + QLatin1Char('/') + package->name);
+      insertRemovePackageIntoTransaction(getSelectedGroup());
+      return;
     }
   }
-  /*else
+
+  QString removeCmd = m_removeCommand;
+  if (removeCmd == QLatin1String("Rcs") )
   {
-    doRemoveAURPackage();
-  }*/
+    checkDependencies = true;
+  }
+
+  int res = 0;
+  for(QModelIndex item: qAsConst(selectedRows))
+  {
+    const PackageRepository::PackageData*const package = m_packageModel->getData(item);
+    if (package == nullptr) {
+      assert(false);
+      continue;
+    }
+
+    if(checkDependencies)
+    {
+      QStringList *targets = Package::getTargetRemovalList(package->name, removeCmd);
+
+      for(const QString& target: qAsConst(*targets))
+      {
+        int separator = target.lastIndexOf(QLatin1String("-"));
+        QString candidate = target.left(separator);
+        separator = candidate.lastIndexOf(QLatin1String("-"));
+        candidate = candidate.left(separator);
+
+        if (candidate != package->name)
+        {
+          dependencies.append(candidate);
+        }
+      }
+
+      if (dependencies.count() > 0)
+      {
+        if (!dependencies.at(0).contains(QLatin1String("HoldPkg was found in")))
+        {
+          res = insertIntoRemovePackageDeps(dependencies);
+          if (res == -1)
+          {
+            return;
+          }
+        }
+      }
+    }
+
+    insertRemovePackageIntoTransaction(package->repository + QLatin1Char('/') + package->name);
+    if (res == 0) checkDependencies = false;
+  }// end of FOR
 }
 
 /*
@@ -362,9 +358,6 @@ void MainWindow::insertGroupIntoRemovePackage()
  */
 void MainWindow::onChangeInstallReason()
 {
-  /*bool isAURSelected=isAURGroupSelected();
-  PackageInfoData pkgInfo;
-  QString installReason;*/
   QHash<QString, QString> pkgList;
   QModelIndexList selectedRows = ui->tvPackages->selectionModel()->selectedRows();
 
@@ -376,21 +369,9 @@ void MainWindow::onChangeInstallReason()
       continue;
     }
 
-    /*if (isAURSelected)
-    {
-      pkgInfo=Package::getInformation(package->name, true);
-      if (pkgInfo.installReason == QStringLiteral("Explicitly installed"))
-      {
-        installReason=QStringLiteral("Explicitly");
-      }
-      else if (pkgInfo.installReason == QStringLiteral("Installed as a dependency for another package"))
-      {
-        installReason=QStringLiteral("As dependency");
-      }
-
-      pkgList.insert(package->name, installReason);
-    }
-    else*/
+    if (SettingsManager::hasPacmanBackend())
+      pkgList.insert(package->name, Package::getInstallReasonByPkgName(package->name));
+    else
       pkgList.insert(package->name, package->installReason);
   }
 
@@ -561,9 +542,10 @@ void MainWindow::insertIntoInstallPackageOptDeps(const QString &packageName)
 /*
  * Inserts all remove dependencies of the current select package into the Transaction Treeview
  * Returns TRUE if the user click OK or ENTER and number of selected packages > 0.
- * Returns FALSE otherwise.
+ * Return <NUMBER of dependencies selected> if the user click OK/ENTER
+ * Return -1 if the user click CANCEL
  */
-bool MainWindow::insertIntoRemovePackageDeps(const QStringList &dependencies)
+int MainWindow::insertIntoRemovePackageDeps(const QStringList &dependencies)
 {
   QList<const PackageRepository::PackageData*> newDeps;
   for(const QString& dep: dependencies)
@@ -588,12 +570,6 @@ bool MainWindow::insertIntoRemovePackageDeps(const QStringList &dependencies)
       QString desc = dep->description;
       int space = desc.indexOf(QLatin1String(" "));
       desc = desc.mid(space+1);
-
-      /*if(dep->repository == StrConstants::getForeignRepositoryName() && dep->description.isEmpty())
-      {
-        desc = Package::getInformationDescription(dep->name, true);
-      }*/
-
       msd->addPackageItem(dep->name, desc, dep->repository);
     }
 
@@ -612,9 +588,13 @@ bool MainWindow::insertIntoRemovePackageDeps(const QStringList &dependencies)
 
     delete msd;
 
-    return (res == QMessageBox::Ok && selectedPackages.count() >= 0);
+    if (res == QMessageBox::Ok)
+    {
+      return selectedPackages.count();
+    }
+    else return -1;
   }
-  else return true;
+  else return 0; //true
 }
 
 /*
@@ -1249,7 +1229,7 @@ void MainWindow::doRemoveAndInstall()
 
   QString ds = Package::kbytesToSize(totalDownloadSize);
 
-  if (installList.count() == 0)
+  if (installList.length() == 0)
   {
     installTargets->append(PackageListData(listOfInstallTargets, QLatin1String(""), QString::number(0)));
     installList.append(StrConstants::getInstall() + QLatin1Char(' ') + listOfInstallTargets);
@@ -1485,9 +1465,9 @@ void MainWindow::doPreDownloadTempYay()
   //Here we start the download thread... and bind its finished state to doInstallYayPackage()
   QFuture<bool> f;
   QEventLoop el;
-  f = QtConcurrent::run(installTempYayHelper);
-  connect(&g_fwInstallTempYayHelper, SIGNAL(finished()), &el, SLOT(quit()));
-  g_fwInstallTempYayHelper.setFuture(f);
+  f = QtConcurrent::run(downloadTempYayHelper);
+  connect(&g_fwDownloadTempYayHelper, SIGNAL(finished()), &el, SLOT(quit()));
+  g_fwDownloadTempYayHelper.setFuture(f);
   el.exec();
   doInstallYayPackage();
 }
@@ -1497,7 +1477,7 @@ void MainWindow::doPreDownloadTempYay()
  */
 void MainWindow::doInstallYayPackage()
 {
-  bool downloadedYay = g_fwInstallTempYayHelper.result();
+  bool downloadedYay = g_fwDownloadTempYayHelper.result();
   if (!downloadedYay)
   {
     //We print a message saying the download did not go right
@@ -1822,7 +1802,7 @@ void MainWindow::doInstall()
 
   QString ds = Package::kbytesToSize(totalDownloadSize);
 
-  if (list.count() == 0)
+  if (list.length() == 0)
   {
     targets->append(PackageListData(listOfTargets, QLatin1String(""), QString::number(0)));
     list.append(listOfTargets);
