@@ -36,10 +36,6 @@
 #include <QRegularExpression>
 #include <QEventLoop>
 #include <QtNetwork/QNetworkReply>
-#include <QJsonArray>
-#include <QJsonDocument>
-#include <QJsonObject>
-#include <QJsonValue>
 
 /*
  * This class abstracts all the relevant package information and services
@@ -74,12 +70,12 @@ QString Package::getBaseName(const QString& p)
 
 	for (int i=1; i<= nameSegment; i++){
     int a=aux.indexOf(QLatin1String("-"));
-		packageBaseName += aux.leftRef(a);
+    packageBaseName += aux.left(a);
 		if (i<nameSegment) packageBaseName += QLatin1String("-");
 		aux = aux.mid(a+1);
 	}
 
-	if (packageBaseName == QLatin1String("")) packageBaseName += p.leftRef(p.indexOf(QLatin1String("-")));
+  if (packageBaseName == QLatin1String("")) packageBaseName += p.left(p.indexOf(QLatin1String("-")));
 	return packageBaseName;
 }
 
@@ -90,21 +86,25 @@ QString Package::getBaseName(const QString& p)
 QString Package::makeURLClickable(const QString &s)
 {
   QString sb = s;
-  QRegExp rx(QStringLiteral("((ht|f)tp(s?))://(\\S)+[^\"|)|(|.|\\s|\\n]"));
-  //QRegExp rx1("^|[\\s]+(www\\.)(\\S)+[^\"|)|(|.|\\s|\\n]");
-  rx.setCaseSensitivity( Qt::CaseInsensitive );
-  //rx1.setCaseSensitivity( Qt::CaseInsensitive );
+  QRegularExpression rx(QStringLiteral("((ht|f)tp(s?))://(\\S)+[^\"|)|(|.|\\s|\\n]"));
+  rx.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
 	int search = 0;
 	int ini = 0;
 
 	//First we search for the 1st pattern: rx
-	while ( (ini = rx.indexIn( sb, search )) != -1 ){
-		QString s1 = rx.cap();
+  //while ( (ini = rx.indexIn( sb, search )) != -1 ){
+  //	QString s1 = rx.cap();
+
+  QRegularExpressionMatch match = rx.match(sb);
+  while (match.hasMatch())
+  {
+    QString s1 = match.captured();
     QString ns;
 
     ns = QLatin1String("<a href=\"") + s1 + QLatin1String("\">") + s1 + QLatin1String("</a>");
     sb.replace( ini, s1.length(), ns);
-		search = ini + (2*s1.length()) + 15;	
+    search = ini + (2*s1.length()) + 15;
+    match = rx.match(sb, search);
 	}
 
   return sb;
@@ -897,7 +897,7 @@ QList<PackageListData> * Package::getForeignToolPackageList(const QString &searc
         {
           QString str = strVotes.first();
           int comma = str.indexOf(QLatin1String(","));
-          pkgVotes = str.midRef(1, comma-1).toInt();
+          pkgVotes = str.mid(1, comma-1).toInt();
         }
         else pkgVotes = 0;
       }
@@ -1024,69 +1024,6 @@ QList<PackageListData> * Package::getForeignToolPackageList(const QString &searc
   return res;
 }
 
-/*
- * Retrieves the list of all AUR packages in the database using Aur rcp (installed + non-installed)
- * given the search parameter
- */
-#ifdef ALPM_BACKEND
-QList<PackageListData> *Package::getAURPackageList(const QString &searchString)
-{
-  QString pkgName, pkgVersion, pkgDescription, pkgOutVersion;
-  int pkgVotes;
-  PackageStatus pkgStatus;
-  QList<PackageListData> * res = new QList<PackageListData>();
-
-  QString searchUrl=QStringLiteral("https://aur.archlinux.org/rpc/?v=5&type=search&by=name-desc&arg=%1");
-  QEventLoop eventLoop;
-  QNetworkRequest request(QUrl{searchUrl.arg(searchString)});
-  QNetworkAccessManager nam;
-  QNetworkReply *r = nam.get(request);
-  QObject::connect(r, SIGNAL(finished()), &eventLoop, SLOT(quit()));
-  eventLoop.exec();
-  QObject::disconnect(r, SIGNAL(finished()), &eventLoop, SLOT(quit()));
-
-  QByteArray contents = r->readAll();
-  QJsonDocument doc = QJsonDocument::fromJson(contents);
-  QJsonObject root = doc.object();
-  QJsonArray results = root[QLatin1String("results")].toArray();
-
-  QString installedVersion;
-  for (int c=0; c<results.count(); ++c)
-  {
-    QJsonObject pkg = results[c].toObject();
-
-    pkgName = pkg[QLatin1String("Name")].toString();
-    pkgVersion = pkg[QLatin1String("Version")].toString();
-    pkgOutVersion.clear();
-    pkgDescription = pkgName + QLatin1String(" ") + pkg[QLatin1String("Description")].toString();
-    pkgVotes = pkg[QLatin1String("NumVotes")].toInt();
-
-    installedVersion = AlpmBackend::getPackageVersion(pkgName);
-
-    if (installedVersion.isEmpty())
-    {
-      pkgStatus = ectn_NON_INSTALLED;
-    }
-    else if (installedVersion == pkgVersion)
-    {
-      pkgStatus = ectn_FOREIGN;
-    }
-    else
-    {
-      pkgStatus = ectn_FOREIGN_OUTDATED;
-    }
-
-    PackageListData pld =
-        PackageListData(pkgName, StrConstants::getForeignRepositoryName(), pkgVersion, pkgDescription, pkgStatus, pkgOutVersion);
-    pld.popularity = pkgVotes;
-
-    res->append(pld);
-  }
-
-  return res;
-}
-#endif
-
 /*
  * Retrieves the list of all KCP packages in the database using Kcp (installed + non-installed)
  * given the search parameter
@@ -1846,6 +1783,16 @@ QString Package::getInstallReason(const QString &pkgInfo)
   return extractFieldFromInfo(QStringLiteral("Install Reason"), pkgInfo);
 }
 
+/*
+ * Retrieves "Install Reason" field of the given package
+ */
+QString Package::getInstallReasonByPkgName(const QString &pkgName)
+{
+  QString pkgInfo = QString::fromUtf8(UnixCommand::getPackageInformation(pkgName, true));
+  QString instReason = getInstallReason(pkgInfo);
+  return getInstallReason(pkgInfo);
+}
+
 /*
  * Retrieves "Installed Size" field of the given package information string represented by pkgInfo
  */
@@ -2317,9 +2264,10 @@ QStringList Package::getContents(const QString& pkgName, bool isInstalled)
   QStringList slResult;
   QByteArray result;
 
-  if (isInstalled)
+  //OLD pkgfile code:
+  /*if (isInstalled)
   {
-    result = UnixCommand::getPackageContentsUsingPacman(pkgName);
+    result = UnixCommand::getPackageContentsUsingPacman(pkgName, isInstalled);
   }
   else if (UnixCommand::getLinuxDistro() == ectn_ARCHBANGLINUX ||
            UnixCommand::getLinuxDistro() == ectn_ARCHLINUX ||
@@ -2328,7 +2276,9 @@ QStringList Package::getContents(const QString& pkgName, bool isInstalled)
            UnixCommand::getLinuxDistro() == ectn_PARABOLA)
   {
     result = UnixCommand::getPackageContentsUsingPkgfile(pkgName);
-  }
+  }*/
+
+  result = UnixCommand::getPackageContentsUsingPacman(pkgName, isInstalled);
 
   QString aux(QString::fromUtf8(result));
   QStringList rsl = aux.split(QStringLiteral("\n"), Qt::SkipEmptyParts);
@@ -2347,7 +2297,12 @@ QStringList Package::getContents(const QString& pkgName, bool isInstalled)
        apps/kdemultimedia-juk  /usr/share/doc/kde/html/en/juk/search-playlist.png */
     else
     {
-      QStringList rsl2;
+      rsl.replaceInStrings(QRegularExpression(pkgName + QLatin1Char(' ')), QLatin1String("/"));
+      rsl.sort();
+      slResult = rsl;
+
+      //OLD pkgfile code:
+      /*QStringList rsl2;
       for(auto line: qAsConst(rsl))
       {
         QStringList slAux = line.split(QStringLiteral("\t"), Qt::SkipEmptyParts);
@@ -2355,7 +2310,7 @@ QStringList Package::getContents(const QString& pkgName, bool isInstalled)
       }
 
       rsl2.sort();
-      slResult = rsl2;
+      slResult = rsl2;*/
     }
   }
 
