@@ -25,7 +25,6 @@
 
 #include "settingsmanager.h"
 #include "unixcommand.h"
-#include "uihelper.h"
 #include "qaesencryption.h"
 
 #include <QString>
@@ -1001,7 +1000,6 @@ void SettingsManager::setAURUserName(const QString &newValue)
 void SettingsManager::setAURPassword(const QString &newValue)
 {
   //We need to encrypt the given newValue
-
   QString aurUserName = getAURUserName();
   if (aurUserName.isEmpty()) return;
 
@@ -1060,4 +1058,22 @@ void SettingsManager::setConsoleFontSize(int newValue)
   instance()->getSYSsettings()->sync();
 }
 
+void SettingsManager::setTerminalColorScheme(const QString &newValue)
+{
+  instance()->getSYSsettings()->setValue(ctn_KEY_TERMINAL_COLOR_SCHEME, newValue);
+  instance()->getSYSsettings()->sync();
+}
+
+void SettingsManager::setTerminalFontFamily(const QString &newValue)
+{
+  instance()->getSYSsettings()->setValue(ctn_KEY_TERMINAL_FONT_FAMILY, newValue);
+  instance()->getSYSsettings()->sync();
+}
+
+void SettingsManager::setTerminalFontPointSize(qreal newValue)
+{
+  instance()->getSYSsettings()->setValue(ctn_KEY_TERMINAL_FONT_POINT_SIZE, newValue);
+  instance()->getSYSsettings()->sync();
+}
+
 //Octopi related --------------------------------------------------------------------
