@@ -32,10 +32,10 @@ QString StrConstants::getQtVersion(){
 
 QString StrConstants::getApplicationCliHelp(){
  QString str = getApplicationName() + QLatin1String(" - ") + ctn_APPLICATION_VERSION /*getApplicationVersion()*/ + QLatin1String("\n") +
-      QLatin1String("\n") + getHelpUsage() + QLatin1String("\n\n") +
-      QLatin1String("\t-version: ") + QObject::tr("show application version.") + QLatin1String("\n") +
-      QLatin1String("\t-sysupgrade: ") + QObject::tr("force a system upgrade at startup.") + QLatin1String("\n") +
-      QLatin1String("\t-sysupgrade-noconfirm: ") + QObject::tr("force a system upgrade at startup, withou asking for confirmation.") +
+     QLatin1String("\n") + getHelpUsage() + QLatin1String("\n\n") +
+     QLatin1String("\t-version: ") + QObject::tr("show application version.") + QLatin1String("\n") +
+     QLatin1String("\t-sysupgrade: ") + QObject::tr("force a system upgrade at startup.") + QLatin1String("\n") +
+     QLatin1String("\t-sysupgrade-noconfirm: ") + QObject::tr("force a system upgrade at startup, withou asking for confirmation.") +
      QLatin1String("\n");
 
  return str;
@@ -366,7 +366,7 @@ QString StrConstants::getExplicitly(){
 }
 
 QString StrConstants::getAsDependency(){
-  return QObject::tr("As dependency");
+  return QObject::tr("As a dependency");
 }
 
 QString StrConstants::getPackager(){
@@ -515,7 +515,8 @@ QString StrConstants::getSyncing(){
 }
 
 QString StrConstants::getPressAnyKey(){
-  return QStringLiteral("Press any key to continue...");
+  //return QStringLiteral("Press any key to continue...");
+  return QStringLiteral("PAKtC");
 }
 
 QString StrConstants::getCouldNotAttachToParent()
