@@ -19,7 +19,7 @@
 */
 
 #include "unixcommand.h"
-#include "strconstants.h"
+//#include "strconstants.h"
 #include "wmhelper.h"
 #include "terminal.h"
 #include <iostream>
@@ -394,7 +394,7 @@ QByteArray UnixCommand::getOutdatedAURPackageList()
  */
 QByteArray UnixCommand::getForeignPackageList()
 {
-  QByteArray result = performQuery(QStringList(QStringLiteral("-Qem")));
+  QByteArray result = performQuery(QStringList(QStringLiteral("-Qm")));
   return result;
 }
 
@@ -457,12 +457,16 @@ QByteArray UnixCommand::getPackageInformation(const QString &pkgName, bool forei
 /*
  * Given a package name, returns a string containing all the files inside it
  */
-QByteArray UnixCommand::getPackageContentsUsingPacman(const QString& pkgName)
+QByteArray UnixCommand::getPackageContentsUsingPacman(const QString& pkgName, bool isInstalled)
 {
   QStringList args;
-  args << QStringLiteral("-Ql");
-  args << pkgName;
 
+  if (isInstalled)
+    args << QStringLiteral("-Ql");
+  else
+    args << QStringLiteral("-Fl");
+
+  args << pkgName;
   QByteArray res = performQuery(args);
   return res;
 }
@@ -663,8 +667,14 @@ bool UnixCommand::doInternetPingTest()
 /*
  * Checks if the given executable is available somewhere in the system
  */
-bool UnixCommand::hasTheExecutable( const QString& exeName )
+bool UnixCommand::hasTheExecutable(const QString& exeName)
 {
+  if (exeName == ctn_OCTOPISUDO)
+    return (QFile::exists(ctn_OCTOPISUDO));
+  else
+    return (QFile::exists(QStringLiteral("/usr/bin/") + exeName));
+
+  /*qDebug() << "Needed to test executable: " << exeName;
   QProcess proc;
   proc.setProcessChannelMode(QProcess::MergedChannels);
   QString sParam = QLatin1String("which ") + exeName;
@@ -679,7 +689,7 @@ bool UnixCommand::hasTheExecutable( const QString& exeName )
   QString out = QString::fromUtf8(proc.readAllStandardOutput());
   proc.close();
 
-  return !(out.isEmpty() || out.count(QStringLiteral("which")) > 0);
+  return !(out.isEmpty() || out.count(QStringLiteral("which")) > 0);*/
 }
 
 /*
